diff --git a/arch/x86/mm/pageattr-test.c b/arch/x86/mm/pageattr-test.c
index 4e8b8c6baccd529453d606a3b7dff5813cb8e1c8..554820265b95d1a4334632d09a7aede7564393cc 100644
--- a/arch/x86/mm/pageattr-test.c
+++ b/arch/x86/mm/pageattr-test.c
@@ -183,7 +183,7 @@ static __init int exercise_pageattr(void)
 
 	}
 	vfree(bm);
-	global_flush_tlb();
+	cpa_flush_all();
 
 	failed += print_split(&sb);
 
@@ -211,7 +211,7 @@ static __init int exercise_pageattr(void)
 		}
 
 	}
-	global_flush_tlb();
+	cpa_flush_all();
 
 	failed += print_split(&sc);
 
diff --git a/arch/x86/mm/pageattr.c b/arch/x86/mm/pageattr.c
index bbe691dd272e21697301e98b3ced936c850dd360..cdd2ea2a2239609185131b730d93ff59d64229a2 100644
--- a/arch/x86/mm/pageattr.c
+++ b/arch/x86/mm/pageattr.c
@@ -33,7 +33,7 @@ void clflush_cache_range(void *addr, int size)
 		clflush(addr+i);
 }
 
-static void flush_kernel_map(void *arg)
+static void __cpa_flush_all(void *arg)
 {
 	/*
 	 * Flush all to work around Errata in early athlons regarding
@@ -45,11 +45,11 @@ static void flush_kernel_map(void *arg)
 		wbinvd();
 }
 
-static void global_flush_tlb(void)
+static void cpa_flush_all(void)
 {
 	BUG_ON(irqs_disabled());
 
-	on_each_cpu(flush_kernel_map, NULL, 1, 1);
+	on_each_cpu(__cpa_flush_all, NULL, 1, 1);
 }
 
 struct clflush_data {
@@ -350,13 +350,13 @@ static int change_page_attr_set_clr(unsigned long addr, int numpages,
 	/*
 	 * On success we use clflush, when the CPU supports it to
 	 * avoid the wbindv. If the CPU does not support it and in the
 	 * error case we fall back to global_flush_tlb (which uses
 	 * wbindv):
 	 */
 	if (!ret && cpu_has_clflush)
 		cpa_flush_range(addr, numpages);
 	else
-		global_flush_tlb();
+		cpa_flush_all();
 
 	return ret;
 }
@@ -350,13 +350,13 @@ static int change_page_attr_set_clr(unsigned long addr, int numpages,
 	 * On success we use clflush, when the CPU supports it to
 	 * avoid the wbindv. If the CPU does not support it and in the
-	 * error case we fall back to global_flush_tlb (which uses
+	 * error case we fall back to cpa_flush_all (which uses
 	 * wbindv):
 	 */